@@ -88,7 +88,7 @@ das_chop_section.das_df <- function(x, conditions, distance.method = NULL,
 
   # Call das_chop_equallength using max section length + 1
   das_chop_equallength(
-    x %>% select(-.data$cont_eff_section),
+    x %>% select(-"cont_eff_section"),
     conditions = conditions,
     seg.km = max(x.summ$dist_sum) + 1, randpicks.load = randpicks.df,
     num.cores = num.cores
